==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GatewayRouteSpecHttp2RouteActionRewrite.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property hostname Host name to rewrite.
 * @property path Exact path to rewrite.
 * @property prefix Specified beginning characters to rewrite.
 */
public data class GatewayRouteSpecHttp2RouteActionRewrite(
    public val hostname: GatewayRouteSpecHttp2RouteActionRewriteHostname? = null,
    public val path: GatewayRouteSpecHttp2RouteActionRewritePath? = null,
    public val prefix: GatewayRouteSpecHttp2RouteActionRewritePrefix? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GatewayRouteSpecHttp2RouteActionRewrite):
            GatewayRouteSpecHttp2RouteActionRewrite = GatewayRouteSpecHttp2RouteActionRewrite(
            hostname = javaType.hostname().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GatewayRouteSpecHttp2RouteActionRewriteHostname.Companion.toKotlin(args0)
                })
            }).orElse(null),
            path = javaType.path().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GatewayRouteSpecHttp2RouteActionRewritePath.Companion.toKotlin(args0)
                })
            }).orElse(null),
            prefix = javaType.prefix().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GatewayRouteSpecHttp2RouteActionRewritePrefix.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GatewayRouteSpecHttp2RouteActionRewrite.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property hostname Host name to rewrite.
 * @property path Exact path to rewrite.
 * @property prefix Specified beginning characters to rewrite.
 */
public data class GatewayRouteSpecHttp2RouteActionRewrite(
    public val hostname: GatewayRouteSpecHttp2RouteActionRewriteHostname? = null,
    public val path: GatewayRouteSpecHttp2RouteActionRewritePath? = null,
    public val prefix: GatewayRouteSpecHttp2RouteActionRewritePrefix? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GatewayRouteSpecHttp2RouteActionRewrite): GatewayRouteSpecHttp2RouteActionRewrite = GatewayRouteSpecHttp2RouteActionRewrite(
            hostname = javaType.hostname().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GatewayRouteSpecHttp2RouteActionRewriteHostname.Companion.toKotlin(args0)
                })
            }).orElse(null),
            path = javaType.path().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GatewayRouteSpecHttp2RouteActionRewritePath.Companion.toKotlin(args0)
                })
            }).orElse(null),
            prefix = javaType.prefix().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GatewayRouteSpecHttp2RouteActionRewritePrefix.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
